@@ -1172,13 +1172,15 @@ class Provider(BaseProvider):
 
     regex = re.compile(timedelta_pattern)
 
-    def unix_time(self, end_datetime=None):
+    def unix_time(self, end_datetime=None, start_datetime=None):
         """
-        Get a timestamp between January 1, 1970 and now
+        Get a timestamp between January 1, 1970 and now, unless passed
+        explicit start_datetime or end_datetime values.
         :example 1061306726
         """
+        start_datetime = self._parse_start_datetime(start_datetime)
         end_datetime = self._parse_end_datetime(end_datetime)
-        return self.generator.random.randint(0, end_datetime)
+        return self.generator.random.randint(start_datetime, end_datetime)
 
     def time_delta(self, end_datetime=None):
         """
@@ -1257,6 +1259,13 @@ class Provider(BaseProvider):
         """
         return self.date_time(end_datetime=end_datetime).time()
 
+    @classmethod
+    def _parse_start_datetime(cls, value):
+        if value is None:
+            return 0
+
+        return cls._parse_date_time(value)
+
     @classmethod
     def _parse_end_datetime(cls, value):
         if value is None:
@@ -1271,9 +1280,9 @@ class Provider(BaseProvider):
             raise ParseError("Can't parse date string `{}`.".format(value))
         parts = parts.groupdict()
         time_params = {}
-        for (name, param) in parts.items():
-            if param:
-                time_params[name] = int(param)
+        for (name_, param_) in parts.items():
+            if param_:
+                time_params[name_] = int(param_)
 
         if 'years' in time_params:
             if 'days' not in time_params:
